#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-5quHCUvnPzs9ojORpO84F0
key:                  pantry-0.8.3-5quHCUvnPzs9ojORpO84F0
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  440cb2f0bf43d74387f7db3865c34818
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-5quHCUvnPzs9ojORpO84F0
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL
    ansi-terminal-1.1-4Fc3pfbWuzJIdO3EFXFaIS base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-6pSjA0DlLiZ7AdPyaseOjM
    casa-types-0.0.3-9teMJe3Q5t5D7lUrFh6C1y
    conduit-1.3.6.1-GX9q6BroOQ8DfdDkcg2QOw
    conduit-extra-1.3.8-DnALaIZUnFk6LCIAvzpD0b containers-0.6.7
    crypton-1.0.4-I0bzTn2woJ4DLB7BtNhDWv
    crypton-conduit-0.2.3-KMdlAHVXR0e44tCjq9C8nX
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-6TS3FbRurIrK6N8uVg8x7G
    generic-deriving-1.14.7-5EVA7USioDvAPoGbgrXr77
    hackage-security-0.6.3.2-CSTt55Xsb5L1aJu4PCTs9T
    hpack-0.38.0-GB8e4WorvNc1xELgNmlFT2
    http-client-0.7.19-KIsPCwAmJfj40FXZ7rXqbo
    http-client-tls-0.3.6.4-CcSwqFxVTByFynBRChiegK
    http-conduit-2.3.9.1-7ZLRntjm6nyKC9BSNItCrg
    http-download-0.2.1.0-Le9kmq3RfSHIggIrL8nLJu
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-91j990LrivP71ivMfH7l0g
    path-0.9.6-AtcUKI46P2FATxYoF4i3fr
    path-io-1.8.2-3NOz3dTMRSb4UOq0Bqa5DR
    persistent-2.14.5.2-9OkhfmcjXJUJAi9BDXJFnj
    persistent-sqlite-2.13.2.0-Jr3G2NwhndZ9l1Rk9b2z9Y
    primitive-0.9.1.0-CIlU66tAMro5ZKIlpCPDD4
    resourcet-1.2.6-K6JBNnVEw7T4VmkwByHPd3
    rio-0.1.24.0-E9Vj8Tqnt8kFAbCMmmpasN
    rio-orphans-0.1.2.0-B4uGuwl9JjvImbjQMIbDap
    rio-prettyprint-0.1.8.0-KAb55WjjuFO52Gok9XP3a8
    tar-conduit-0.4.1-7sOGLcR71nm3uKCFA7mSzm text-2.0.2
    text-metrics-0.3.3-2PYDnjDl0Gj9Dd2XOfPpio time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-CNHdcuBo4WyE8NnkOFSrdm
    unliftio-0.2.25.1-H2bxXnnkRB0DM3bojqNUxO
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    vector-0.13.2.0-BkeaBlIIAt9GprLstCadki
    yaml-0.11.11.2-4nq91yAXiWkLGvTAafAlR5
    zip-archive-0.4.3.2-DEAU29gCy1yL8Hmh2HmXwp

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

